
Changelog
---------

0.5 (2015-02-26)
~~~~~~~~~~~~~~~~

- Add Option to Organization for how to Display Memberships #5.
  [msom]

- Change column widths of membership tables in PDF.
  [msom]

- Add PDF Export View to Organization #4.
  [msom]

0.4 (2015-02-24)
~~~~~~~~~~~~~~~~

- Limit the visible levels in the table of contents of the PDF.
  [msom]

- Use less page breaks in the PDF.
  [msom]

- Fix displaying memberships with deleted members.
  [msom]

0.3 (2015-02-09)
~~~~~~~~~~~~~~~~

- Use a more uncommon separator in XLS import/export.
  [msom]

- Add data migration script.
  [msom]

- Add tests.
  [msom]

- Update bootstrap and setuptools.
  [msom]

0.2 (2015-01-21)
~~~~~~~~~~~~~~~~

- Change global_allow to True. See:
  https://github.com/seantis/seantis.people/issues/32
  [href]

- Show parent organization in people list #3
  [msom]

- Add PDF export of organizations #2
  [msom]

0.1 (2014-12-04)
~~~~~~~~~~~~~~~~

- Initial release.
  [msom]
